function [passed,results] = run_rtccode_tests(test_case)
% test runner for rtccode

% F. Felici, EPFL federico.felici@epfl.ch

if nargin==0 || isempty(test_case)
  test_case = 'algos'; % default
end
test_case = lower(test_case);

%% Import some classes we need
import matlab.unittest.selectors.HasTag;
import matlab.unittest.constraints.ContainsSubstring;
import matlab.unittest.selectors.HasName;

%% initialize paths
rtccode_paths

%% populate suite
switch lower(test_case)
  case 'algos'
    fprintf('populating test suite with all SCDalgo tests... \n')
    suite = testsuite('algos','IncludingSubfolders',true,'superclass','SCDalgo_test');
    fprintf('done \n')
  case 'unit'
    s = HasTag('Unit');
    suite = [matlab.unittest.TestSuite.fromFolder('core/tests',s),...
             matlab.unittest.TestSuite.fromFolder(fullfile('tbx','tests'),s),...
             testsuite(fullfile('core','classes'),'IncludingSubfolders',true)];
  case 'expcodes'
    s = HasTag('expcodes');
    suite = matlab.unittest.TestSuite.fromFolder('core/tests',s);
  otherwise
    error('unknown test_case %s',test_case)
end

assert(~isempty(suite),'empty test suite');

%% run it
fprintf('Start test case: %s\n%s\n\n',test_case,datestr(now));
results = run(suite);
disp(table(results));
fprintf('\nTotal test duration: %5.2fs\n',sum(table(results).Duration))

%% Display results
if all([results.Passed])
  fprintf('\nPassed all tests\n')
  passed = true;
elseif any([results.Failed])
  fprintf('\nSome tests Failed\n')
  disp(table(results([results.Failed])))
  passed = false;
elseif any([results.Incomplete])
  fprintf('\nSome tests Incomplete\n')
  disp(table(results([results.Incomplete])));
  passed = true; % pass tests even if some were skipped
else
  error('something is very wrong - please check')
end
